@@ -614,7 +614,7 @@ class BreakPoints(object):
     # Register style element
     _styleElements = [  (   'Editor.BreakPoints',
                             'The fore- and background-color of the breakpoints.',
-                            'fore:#F66,back:#EEE', 
+                            'fore:#F66,back:#dfdfe1', 
                         ) ]
     
     class __BreakPointArea(QtGui.QWidget):
@@ -624,6 +624,8 @@ class BreakPoints(object):
         def __init__(self, codeEditor):
             QtGui.QWidget.__init__(self, codeEditor)
             self.setCursor(QtCore.Qt.PointingHandCursor)
+            self.setMouseTracking(True)
+            self._virtualBreakpoint = 0
         
         def _getY(self, pos):
             tmp = self.mapToGlobal(pos)
@@ -632,6 +634,18 @@ class BreakPoints(object):
         def mousePressEvent(self, event):
             self._toggleBreakPoint( self._getY(event.pos()))
         
+        def mouseMoveEvent(self, event):
+            y = self._getY(event.pos())
+            editor = self.parent()
+            cursor = editor.textCursor()
+            c1 = editor.cursorForPosition(QtCore.QPoint(0,y))
+            self._virtualBreakpoint = c1.blockNumber() + 1
+            self.update()
+        
+        def leaveEvent(self, event):
+            self._virtualBreakpoint = 0
+            self.update()
+        
         def _toggleBreakPoint(self, y):
             # Get breakpoint corresponding to pressed pos
             editor = self.parent()
@@ -682,45 +696,66 @@ class BreakPoints(object):
             
             # Get debug indicator and list of sorted breakpoints
             debugBlockIndicator = editor._debugLineIndicator-1
+            virtualBreakpoint = self._virtualBreakpoint-1
             blocknumbers = [i-1 for i in sorted(self.parent()._breakPoints)]
-            if not (blocknumbers or debugBlockIndicator > 0):
+            if not (blocknumbers or 
+                    editor._debugLineIndicator or
+                    editor._debugLineIndicators or
+                    virtualBreakpoint > 0):
                 return
-            if not blocknumbers:  blocknumbers.append(-1)  # Safes a test below
             
             # Get cursor
             cursor = editor.cursorForPosition(QtCore.QPoint(0,y1))
             
-            # Init painter with font and color
+            # Get start block number and bullet offset in pixels
+            startBlockNumber = cursor.block().blockNumber()
+            bulletOffset = editor.contentOffset().y() + bulletWidth * 0.25
+            
+            # Prepare painter
             painter.setPen(QtGui.QColor('#777'))
             painter.setBrush(format.fore)
             painter.setRenderHint(painter.Antialiasing)
             
             
-            #Repainting always starts at the first block in the viewport,
-            #regardless of the event.rect().y(). Just to keep it simple
-            while True:
-                blockNumber = cursor.block().blockNumber()
-                
-                # Done?
-                if blockNumber > blocknumbers[-1] and blockNumber > debugBlockIndicator:
-                    break
-                if not cursor.block().next().isValid():
-                    break #Reached end of the text
-                
-                # Draw
-                if blockNumber in blocknumbers:
-                    y = editor.cursorRect(cursor).center().y()
-                    y -= bulletWidth * 0.5
+            # Draw breakpoints
+            for blockNumber in blocknumbers:
+                if blockNumber < startBlockNumber:
+                    continue
+                # Get block
+                block = editor.document().findBlockByNumber(blockNumber)
+                if block.isValid():
+                    y = editor.blockBoundingGeometry(block).y() + bulletOffset
                     painter.drawEllipse(margin, y, bulletWidth, bulletWidth)
-                if blockNumber == debugBlockIndicator:
-                    y = editor.cursorRect(cursor).center().y()
-                    y -= bulletWidth * 0.25
-                    painter.setBrush(QtGui.QColor('#6F6'))
-                    #painter.drawRect(margin, y, bulletWidth, 0.5*bulletWidth)
+            
+            # Draw *the* debug marker
+            if debugBlockIndicator > 0:
+                painter.setBrush(QtGui.QColor('#6F6'))
+                # Get block
+                block = editor.document().findBlockByNumber(debugBlockIndicator)
+                if block.isValid():
+                    y = editor.blockBoundingGeometry(block).y() + bulletOffset
+                    y += 0.25 * bulletWidth
                     painter.drawEllipse(margin, y, bulletWidth, 0.5*bulletWidth)
-                    painter.setBrush(format.fore)
-                
-                cursor.movePosition(cursor.NextBlock)
+            
+            # Draw other debug markers
+            for debugLineIndicator in editor._debugLineIndicators:
+                debugBlockIndicator = debugLineIndicator - 1
+                painter.setBrush(QtGui.QColor('#DDD'))
+                # Get block
+                block = editor.document().findBlockByNumber(debugBlockIndicator)
+                if block.isValid():
+                    y = editor.blockBoundingGeometry(block).y() + bulletOffset
+                    y += 0.25 * bulletWidth
+                    painter.drawEllipse(margin, y, bulletWidth, 0.5*bulletWidth)
+            
+            # Draw virtual break point
+            if virtualBreakpoint > 0:
+                painter.setBrush(QtGui.QColor(0,0,0,0))
+                # Get block
+                block = editor.document().findBlockByNumber(virtualBreakpoint)
+                if block.isValid():
+                    y = editor.blockBoundingGeometry(block).y() + bulletOffset
+                    painter.drawEllipse(margin, y, bulletWidth, bulletWidth)
             
             # Done
             painter.end()
@@ -734,6 +769,7 @@ class BreakPoints(object):
         self.addLeftMargin(BreakPoints, self.getBreakPointAreaWidth)
         self._breakPoints = set()
         self._debugLineIndicator = 0
+        self._debugLineIndicators = set()
     
     
     def breakPoints(self):
@@ -749,14 +785,28 @@ class BreakPoints(object):
         self.breakPointsChanged.emit(self)
     
     
-    def setDebugLineIndicator(self, linenr):
+    def setDebugLineIndicator(self, linenr, active=True):
         """ Set the debug line indicator to the given line number.
         If None or 0, the indicator is hidden.
         """
         linenr = int(linenr or 0)
-        if linenr != self._debugLineIndicator:
-            self._debugLineIndicator = linenr
-            self.__breakPointArea.update()
+        if not linenr:
+            # Remove all indicators
+            if self._debugLineIndicator or self._debugLineIndicators:
+                self._debugLineIndicator = 0
+                self._debugLineIndicators = set()
+                self.__breakPointArea.update()
+        elif active:
+            # Set *the* indicator
+            if linenr != self._debugLineIndicator:
+                self._debugLineIndicators.discard(linenr)
+                self._debugLineIndicator = linenr
+                self.__breakPointArea.update()
+        else:
+            # Add to set of indicators
+            if linenr not in self._debugLineIndicators:
+                self._debugLineIndicators.add(linenr)
+                self.__breakPointArea.update()
     
     
     def getBreakPointAreaWidth(self):
