@@ -342,6 +342,15 @@ class IepEditor(BaseTextCtrl):
     
     
     ##
+    
+    
+    def justifyText(self):
+        """ Overloaded version of justifyText to make it use our
+        configurable justificationwidth.
+        """
+        super().justifyText(iep.config.settings.justificationWidth)
+    
+    
     def showRunCursor(self, cursor):
         """
         Momentarily highlight a piece of code to show that this is being executed
@@ -477,9 +486,18 @@ class IepEditor(BaseTextCtrl):
         if self.testWhetherFileWasChanged():
             return
         
-        # Get text, convert line endings
+        # Get text
         text = self.toPlainText()
-        text = text.replace('\n', self.lineEndings)
+        
+        # Convert line endings (optionally remove trailing whitespace
+        if iep.config.settings.removeTrailingWhitespaceWhenSaving:
+            lines = []
+            for line in text.splitlines():
+                lines.append(line.rstrip())
+            text = self.lineEndings.join(lines)
+            self.setPlainText(text)
+        else:
+            text.replace('\n', self.lineEndings)
         
         # Make bytes
         bb = text.encode(self.encoding)
@@ -587,7 +605,24 @@ class IepEditor(BaseTextCtrl):
         #Apply this function to all blocks
         self.doForSelectedBlocks(uncommentBlock)
 
-
+    def gotoDef(self):
+        """
+        Goto the definition for the word under the cursor
+        """
+        
+        # Get name of object to go to
+        cursor = self.textCursor()
+        if not cursor.hasSelection():
+            cursor.select(cursor.WordUnderCursor)
+        word = cursor.selection().toPlainText()
+        
+        # Send the open command to the shell
+        s = iep.shells.getCurrentShell()
+        if s is not None:
+            if word and word.isidentifier():
+                s.executeCommand('open %s\n'%word)
+            else:
+                s.write('Invalid identifier %r\n' % word)
     
     
     ## Introspection processing methods
