@@ -19,6 +19,7 @@ from pyzolib import ssdf, paths
 
 import iep
 from iep.iepcore.icons import IconArtist
+from iep.iepcore import commandline
 from pyzolib.qt import QtCore, QtGui
 from iep.iepcore.splash import SplashWidget
 
@@ -115,6 +116,15 @@ class MainWindow(QtGui.QMainWindow):
         if not iep.config.shellConfigs2:
             from iep.iepcore.kernelbroker import KernelInfo
             iep.config.shellConfigs2.append( KernelInfo() )
+        
+        # Focus on editor
+        e = iep.editors.getCurrentEditor()
+        if e is not None:
+            e.setFocus()
+        
+        # Handle any actions
+        commandline.handle_cmd_args()
+    
     
     # To force drawing ourselves
     def paintEvent(self, event):
@@ -348,6 +358,9 @@ class MainWindow(QtGui.QMainWindow):
         # Save settings
         iep.saveConfig()
         
+        # Stop command server
+        commandline.stop_our_server()
+        
         # Proceed with closing...
         result = iep.editors.closeAll()
         if not result:
@@ -524,12 +537,13 @@ def loadFonts():
     iep.codeeditor.Manager.setDefaultFontFamily('DejaVu Sans Mono')
     
     # Load fonts that are in the fonts directory
-    for fname in os.listdir(fontDir):
-        if os.path.splitext(fname)[1].lower() in ['.otf', '.ttf']:
-            try:
-                db.addApplicationFont( os.path.join(fontDir, fname) )
-            except Exception as err:
-                print('Could not load font %s: %s' % (fname, str(err)))
+    if os.path.isdir(fontDir):
+        for fname in os.listdir(fontDir):
+            if os.path.splitext(fname)[1].lower() in ['.otf', '.ttf']:
+                try:
+                    db.addApplicationFont( os.path.join(fontDir, fname) )
+                except Exception as err:
+                    print('Could not load font %s: %s' % (fname, str(err)))
 
 
 class _CallbackEventHandler(QtCore.QObject):
@@ -565,3 +579,66 @@ def callLater(callback, *args):
 _callbackEventHandler = _CallbackEventHandler()   
 iep.callLater = callLater
 
+
+_SCREENSHOT_CODE = """
+import random
+
+numerator = 4
+
+def get_number():
+    # todo: something appears to be broken here
+    val = random.choice(range(10))
+    return numerator / val
+
+class Groceries(list):
+    \"\"\" Overloaded list class.
+    \"\"\"
+    def append_defaults(self):
+        spam = 'yum'  
+        pie = 3.14159
+        self.extend([spam, pie])
+
+class GroceriesPlus(Groceries):
+    \"\"\" Groceries with surprises!
+    \"\"\"
+    def append_random(self):
+        value = get_number()
+        self.append(value)
+
+# Create some groceries
+g = GroceriesPlus()
+g.append_defaults()
+g.append_random()
+
+"""
+
+def screenshotExample(width=1244, height=700):
+    e = iep.editors.newFile()
+    e.editor.setPlainText(_SCREENSHOT_CODE)
+    iep.main.resize(width, height)
+
+def screenshot(countdown=5):
+    QtCore.QTimer.singleShot(countdown*1000, _screenshot)
+
+def _screenshot():
+    # Grab
+    print('SNAP!')
+    pix = QtGui.QPixmap.grabWindow(iep.main.winId())
+    #pix = QtGui.QPixmap.grabWidget(iep.main)
+    # Get name
+    i = 1
+    while i > 0:
+        name = 'iep_screen_%s_%02i.png' % (sys.platform, i)
+        fname = os.path.join(os.path.expanduser('~'), name)
+        if os.path.isfile(fname):
+            i += 1
+        else:
+            i = -1
+    # Save screenshot and a thumb
+    pix.save(fname)
+    thumb = pix.scaledToWidth(500, QtCore.Qt.SmoothTransformation)
+    thumb.save(fname.replace('screen', 'thumb'))
+    print('Screenshot and thumb saved in', os.path.expanduser('~'))
+
+iep.screenshot = screenshot
+iep.screenshotExample = screenshotExample
