@@ -1044,6 +1044,9 @@ class EditorContextMenu(Menu):
             icons.comment_delete, self._editItemCallback, "uncommentCode")
         self.addItem(translate("menu", "Justify comment/docstring::: Reshape the selected text so it is aligned to around 70 characters."), 
             icons.text_align_justify, self._editItemCallback, "justifyText")
+        self.addSeparator()
+        self.addItem(translate("menu", "Goto Definition ::: Go to definition of word under cursor."),
+            icons.debug_return, self._editItemCallback, "gotoDef")
         
         # This is a subset of the run menu. Copied manually.
         self.addSeparator()
@@ -1418,6 +1421,12 @@ class HelpMenu(Menu):
         if iep.pyzo_mode:
             issues_url = "http://pyzo.org/issues.html"
         
+        
+        if False:  # pyzo mode!  
+            # Work in progress
+            self.addItem(translate("menu", "Pyzo docs ::: Documentation on Python and the Scipy Stack."), 
+                icons.help, self._showPyzoDocs)
+        
         if iep.pyzo_mode:
             self.addUrlItem(translate("menu", "Pyzo Website ::: Open the Pyzo website in your browser."), 
                 icons.help, "http://www.pyzo.org")
@@ -1496,7 +1505,21 @@ class HelpMenu(Menu):
         from iep.iepcore.about import AboutDialog
         m = AboutDialog(self)
         m.exec_()
-
+    
+    
+    def _showPyzoDocs(self):
+        # Get filename of doc collection
+        dirname = os.path.join(sys.prefix, 'share', 'pyzodocs')
+        #dirname = os.path.join('/home/almar/projects/pyzo_latest', 'share', 'pyzodocs')
+        fname = os.path.join(dirname, 'py.qhc')
+        
+        # Get exename of assistant
+        dirname = os.path.join(sys.prefix, 'bin', )
+        #dirname = os.path.join('/home/almar/projects/pyzo_latest', 'bin')
+        exename = os.path.join(dirname, 'assistant')
+        
+        import subprocess
+        iep._assistant = subprocess.Popen([exename , '-collectionFile', fname])
 
 
 class SettingsMenu(Menu):
