@@ -519,7 +519,7 @@ class DebugStack(QtGui.QToolButton):
             self.setMenu(None)
             self.setText('')  #(self._baseText)
             self.setEnabled(False)
-            iep.editors.setDebugLineIndicator('', 0)
+            iep.editors.setDebugLineIndicators(None)
         
         else:
             # Get the current frame
@@ -532,6 +532,7 @@ class DebugStack(QtGui.QToolButton):
             # Fill trace
             for i in range(len(frames)):
                 thisIndex = i + 1
+                # Set text for action
                 text = '{}: File "{}", line {}, in {}'
                 text = text.format(thisIndex, *frames[i])
                 action = menu.addAction(text)
@@ -540,9 +541,18 @@ class DebugStack(QtGui.QToolButton):
                 if thisIndex == index:
                     action._isCurrent = True
                     theAction = action
-                    # Send notice to editor stack
-                    filename, linenr, func = frames[i]
-                    iep.editors.setDebugLineIndicator(filename, linenr)
+                    self.debugFocus(text.split(': ',1)[1])  # Load editor
+            
+            # Get debug indicators
+            debugIndicators = []
+            for i in range(len(frames)):
+                thisIndex = i + 1
+                filename, linenr, func = frames[i]
+                debugIndicators.append((filename, linenr))
+                if thisIndex == index:
+                    break
+            # Set debug indicators
+            iep.editors.setDebugLineIndicators(*debugIndicators)
             
             # Highlight current item and set the button text
             if theAction:
@@ -569,6 +579,10 @@ class DebugStack(QtGui.QToolButton):
         # Cannot open <console>            
         if filename == '<console>':
             return 'Stack frame is <console>.'
+        elif filename.startswith('<ipython-input-'):
+            return 'Stack frame is IPython input.'
+        elif filename.startswith('<'):
+            return 'Stack frame is special name'
         # Go there!
         result = iep.editors.loadFile(filename)
         if not result:
